@@ -17,7 +17,7 @@ import pickle
 from random import choice
 import re
 import smtplib
-from subprocess import run
+from subprocess import run, check_output
 import sys
 import time
 from tqdm.auto import tqdm
@@ -381,10 +381,10 @@ def save(obj, path, mode_pre='w', verbose=True):
         Object to save. This will be pickled/jsonified/zipped inside the
         function - do not convert it before-hand.
     path: str
-        File name to save object to. Should end with .txt, .pkl, .zip, or
-        .json depending on desired output format. If .zip is used, object will
-        be zipped and then pickled. (.sh extension is also allowed and will be
-        treated identically to .txt.)
+        File name to save object to. Should end with .txt, .sh, md, .pkl, .zip,
+        or .json depending on desired output format. If .zip is used, object
+        will be zipped and then pickled. (.sh and .md will be treated
+        identically to .txt.)
     mode_pre: str
         Determines whether to write or append text. One of ('w', 'a').
     verbose: bool
@@ -398,7 +398,7 @@ def save(obj, path, mode_pre='w', verbose=True):
     path = Path(path)
     os.makedirs(path.parent, exist_ok=True)
     if verbose: print(f'Writing data to {path}.')
-    if path.suffix[1:] in ('txt', 'sh'):
+    if path.suffix[1:] in ('txt', 'sh', 'md', 'py'):
         with path.open(mode_pre) as f:
             f.write(obj)
     else:
@@ -414,7 +414,7 @@ def load(path, verbose=True):
     ----------
     path : str
         File to load. File type will be inferred from extension. Must be one of
-        '.txt', '.json', '.pkl', or '.zip'.
+        '.txt', '.sh', 'md', '.json', '.pkl', or '.zip'.
     verbose : bool, optional
         If True, will print message stating where object was loaded from.
 
@@ -423,7 +423,7 @@ def load(path, verbose=True):
     object: The Python object that was pickled to the specified file.
     """
     path = Path(path)
-    if path.suffix[1:] in ('txt', 'sh'):
+    if path.suffix[1:] in ('txt', 'sh', 'md', 'py'):
         return path.read_text()
 
     opener, mode, saver = _read_write_args(str(path), 'r')
@@ -1618,7 +1618,7 @@ def ngrams(word, n=3, step=1, drop_last=False):
     return ngrams_
 
 
-def shell(cmd):
+def shell(cmd, return_output=True):
     """Execute shell command (between subprocess and os, there's ~5 different
     ways to do this and I always forget which I want. This is just a way for me
     to choose once and not have to decide again. There are rare situations
@@ -1630,13 +1630,23 @@ def shell(cmd):
     ----------
     cmd: str
         Example: 'ls *.csv'
+    return_output: bool
+        If True, return the output of the command: e.g. if cmd is
+        'pip show requests', this would return a string containing information
+        about the version of the requests library you have installed. If False,
+        we return a tuple of (return code (0/1), stderr, stdout). I've noticed
+        the latter 2 are usually None though - need to read more into
+        subprocess docs to figure out why this is happening.
 
     Returns
     -------
     tuple: returncode (int), stderr, stdout. I believe stderr and stdout are
     None if nothing is returned and str otherwise.
     """
-    res = run(cmd.split())
+    parts = cmd.split()
+    if return_output:
+        return check_output(parts).decode()
+    res = run(parts)
     return res.returncode, res.stderr, res.stdout
 
 
